summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spells4.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-10-03 18:56:11 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-10-03 18:56:11 +0000
commit774610f0402dc15c10a1a39105e2427484364006 (patch)
treed920ec3236d745ce5fcba9a4a4250e49cde18c56 /crawl-ref/source/spells4.cc
parent3c5ec5ee05c0c463dd8b5cfa98fb71a2e88405d7 (diff)
downloadcrawl-ref-774610f0402dc15c10a1a39105e2427484364006.tar.gz
crawl-ref-774610f0402dc15c10a1a39105e2427484364006.zip
Implement [2040773]: Make Petrify an Enchantment/Earth spell (since it's
a replacement for an Enchantment spell, and the only other Transmigration spell that changes things to stone doesn't work on undead, while this does), and make Lee's Rapid Deconstruction damage a fully petrified monster in the same way it does a statue (except that the blast is described as "petrified fragments", and is the same color as the monster). git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@7107 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/spells4.cc')
-rw-r--r--crawl-ref/source/spells4.cc26
1 files changed, 21 insertions, 5 deletions
diff --git a/crawl-ref/source/spells4.cc b/crawl-ref/source/spells4.cc
index 21052d9ba4..ddea6a6dd4 100644
--- a/crawl-ref/source/spells4.cc
+++ b/crawl-ref/source/spells4.cc
@@ -1841,12 +1841,28 @@ bool cast_fragmentation(int pow, const dist& spd)
break;
default:
- beam.damage.num = 1; // to mark that a monster was targetted
+ // Petrified monsters can be exploded.
+ if (mons_is_petrified(&menv[mon]))
+ {
+ explode = true;
+ beam.ex_size = 2;
+ beam.name = "blast of petrified fragments";
+ beam.colour = menv[mon].colour;
+ beam.damage.num = 3;
+ if (player_hurt_monster(mon, roll_dice(beam.damage)))
+ beam.damage.num++;
+ break;
+ }
+ else
+ {
+ // Mark that a monster was targetted.
+ beam.damage.num = 1;
- // Yes, this spell does lousy damage if the
- // monster isn't susceptible. -- bwr
- player_hurt_monster(mon, roll_dice(1, 5 + pow / 25));
- goto do_terrain;
+ // Yes, this spell does lousy damage if the monster
+ // isn't susceptible. -- bwr
+ player_hurt_monster(mon, roll_dice(1, 5 + pow / 25));
+ goto do_terrain;
+ }
}
mpr(explode_msg.c_str());